# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v3.20.0~54ea14c',
    built_at='2023-02-07 12:23:39Z',
    sha='54ea14ca938517c1ad8037bf9144f9bce919181b',
    branch='HEAD',
    tag='v3.20.0',
)
